@@ -331,6 +331,20 @@ COLOR_REGEXP = re.compile('\x01(.*?)\x02(.*?)\x03+')
 TOPIC_NAME_REGEXP = re.compile('.*\x02(.*?)\x03+')
 
 
+HORIZONTAL = 'horizontal'
+VERTICAL = 'vertical'
+TREE = 'tree'
+DETAILS = 'details'
+
+# Split orientation of the main widget. One of:
+# - None: orientation depends on the screen size
+# - HORIZONTAL: tree and diff panes are horizontally packed
+# - VERTICAL: tree and diff panes are vertically packed
+# - TREE: maximalize the tree pane
+# - DETAILS: maximalize the PATCH pane
+DEFAULT_MAIN_VIEW = None
+
+
 CMD_FILTER = 'filter'
 CMD_SEARCH = 'search'
 CMD_REFRESH = 'refresh'
@@ -350,6 +364,9 @@ CMD_MENU = 'menu'
 CMD_ESCAPE = 'escape'
 CMD_SCROLL_LEFT = 'scroll left'
 CMD_SCROLL_RIGHT = 'scroll right'
+CMD_SPLIT_HORIZONTALLY = 'split horizontally'
+CMD_SPLIT_VERTICALLY = 'split vertically'
+CMD_MAXIMALIZE = 'maximalize'
 CURSOR_UP_NEXT_PACKED = 'up next packed'
 CURSOR_DOWN_NEXT_PACKED = 'down next packed'
 CURSOR_PAGE_UP_NEXT_PACKED = 'page up next packed'
@@ -387,6 +404,10 @@ def keybindings_default():
     command_map['meta home'] = CURSOR_MAX_LEFT_NEXT_PACKED
     command_map['meta end'] = CURSOR_MAX_RIGHT_NEXT_PACKED
 
+    command_map['-'] = CMD_SPLIT_HORIZONTALLY
+    command_map['|'] = CMD_SPLIT_VERTICALLY
+    command_map['='] = CMD_MAXIMALIZE
+
     command_map['ctrl f'] = CMD_FILTER
     command_map['/'] = CMD_SEARCH
     command_map['n'] = CMD_NEXT_MATCH
@@ -413,6 +434,9 @@ def keybindings_mouse():
     command_map[('ctrl mouse press', 4)] = CMD_PREV_MATCH
     command_map[('ctrl mouse press', 5)] = CMD_NEXT_MATCH
 
+    command_map[('ctrl mouse press', 2)] = CMD_SPLIT_VERTICALLY
+    command_map[('ctrl mouse press', 3)] = CMD_SPLIT_HORIZONTALLY
+
 
 def keybindings_vim():
     command_map['ctrl w'] = CMD_NEXT_SELECTABLE
@@ -432,6 +456,10 @@ def keybindings_vim():
     command_map['ESC'] = CMD_ESCAPE
     command_map['ctrl c'] = CMD_ESCAPE
 
+    command_map['ctrl s'] = CMD_SPLIT_HORIZONTALLY
+    command_map['ctrl v'] = CMD_SPLIT_VERTICALLY
+    command_map['ctrl t'] = CMD_MAXIMALIZE
+
     command_map['ctrl f'] = CMD_FILTER
     command_map['/'] = CMD_SEARCH
     command_map['n'] = CMD_NEXT_MATCH
@@ -478,6 +506,10 @@ def keybindings_emacs():
     command_map['esc'] = CMD_ESCAPE
     command_map['ctrl g'] = CMD_ESCAPE
 
+    command_map['meta 3'] = CMD_SPLIT_VERTICALLY
+    command_map['meta 2'] = CMD_SPLIT_HORIZONTALLY
+    command_map['meta 1'] = CMD_MAXIMALIZE
+
     command_map['ctrl f'] = CMD_FILTER
     command_map['/'] = CMD_SEARCH
     command_map['n'] = CMD_NEXT_MATCH
