@@ -1,4 +1,8 @@
-class HgNotFoundError(FileNotFoundError):
+class CriticalError(Exception):
+    """Raise for any non recoverable error"""
+
+
+class HgNotFoundError(CriticalError):
     """Raised when the Mercurial executable was not found."""
 
     def __init__(self):
@@ -6,5 +10,6 @@ class HgNotFoundError(FileNotFoundError):
             'Could not found a proper `hg` executable.'
             '\nUse --with-hg to specify the executable path.')
 
-class RepositoryNotFound(FileNotFoundError):
+
+class RepositoryNotFound(CriticalError):
     """Raised when not repository was found."""
